--
-- speedSound
-- simple Script to add a sound with depencies between volume and vehicle speed
--
-- @author  Sven777b
-- @date  29.08.2012
-- 
-- moddesc: <specialization name="speedSound" className="speedSound" filename="speedSound.lua" />
-- vehicle : <speedSound file="soundfile.wav" pitch="1.0" minVol="0" maxVol="1" maxSpeed="50" />

speedSound = {};

function speedSound.prerequisitesPresent(specializations)
    return true;
end;

function speedSound:load(xmlFile)
    local speedSound = getXMLString(xmlFile, "vehicle.speedSound#file");
    if speedSound ~= nil and speedSound ~= "" then
        speedSound = Utils.getFilename(speedSound, self.baseDirectory);
        self.speedSound = createSample("speedSound");
        loadSample(self.speedSound, speedSound, false);
        local pitch = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.speedSound#pitch"), 0);
        setSamplePitch(self.speedSound, pitch);
        self.speedSoundMinVolume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.speedSound#minVol"), 0);
        self.speedSoundMaxVolume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.speedSound#maxVol"), 1);
        self.speedSoundMaxSpeed = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.speedSound#maxSpeed"), 50);
    end;

end;

function speedSound:delete()
	if self.speedSound ~= nil then
		if self.speedSoundActive then
			stopSample(self.speedSound);
			self.speedSoundActive = false;
		end;
		delete(self.speedSound);
	end;
end;

function speedSound:mouseEvent(posX, posY, isDown, isUp, button)
end;

function speedSound:keyEvent(unicode, sym, modifier, isDown)
end;

function speedSound:update(dt)
	if self.speedSound ~= nil then
		if self:getIsActive() then
			local kmh = self.lastSpeed*3600;
			if kmh > 1 and not self.speedSoundActive then
				playSample(self.speedSound,0,0,0);
				self.speedSoundActive = true;
			elseif kmh <= 1 and self.speedSoundActive then
				stopSample(self.speedSound);
				self.speedSoundActive = false;
			end;
			local percent = math.min(1, (kmh/self.speedSoundMaxSpeed));
			local vol = ((self.speedSoundMaxVolume - self.speedSoundMinVolume) * percent) + self.speedSoundMinVolume;
			setSampleVolume(self.speedSound, vol);
		else
			stopSample(self.speedSound);
			self.speedSoundActive = false;
		end;
	end;
end;

function speedSound:draw()
end;
